@@ -1,21 +1,22 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -W
 package AI::MicroStructure;
 use strict;
 use warnings;
 use Carp;
 use Digest::MD5 qw(md5 md5_hex md5_base64);
 use Digest::SHA1  qw(sha1 sha1_hex sha1_base64);
+use Try::Tiny;
 use File::Basename;
 use File::Spec;
 use File::Glob;
 use Data::Dumper;
+use Data::Printer;
 use AI::MicroStructure::Util;
-
+use Carp qw(croak);
 
 our $absstructdir = "";
 our $structdir = "";
-our @CWD=();
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 our $Structure = 'any'; # default structure
 our $CODESET = 'utf8';
 our $LANG = '';
@@ -33,7 +34,7 @@ our @a=();
 
 our ($init,$new,$drop,$available,$lib,
      $list,$use,$off,$switch,$mirror,
-     $version,$help,$write)  = (0,0,0,0,0,0,0,0,0,0,0,0,0);
+     $version,$help,$write,$verbose)  = (0,0,0,0,0,0,0,0,0,0,0,0,0,0);
 
 eval "\$$_=1; " for @ARGV;
 
@@ -42,40 +43,44 @@ eval "\$$_=1; " for @ARGV;
 if( grep{/\bnew\b/} @ARGV ){ $new = 1; cleanArgs("new"); }
 if( grep{/\bwrite\b/} @ARGV ){ $write = 1; cleanArgs("write");  };
 if( grep{/\bdrop\b/} @ARGV ){ $drop = 1; cleanArgs("drop");  };
+if( grep{/\bverbose\b/} @ARGV ){ $verbose = 1; cleanArgs("verbose");  };
 
 our $StructureName = $ARGV[0]; # default structure
 our $structure = $ARGV[0]; # default structure
 
+our $state  = AI::MicroStructure::Util::config();
+
+our @CWD=();
+push @CWD ,  $state->{path}->{"cwd/structures"};
+our $config = $state->{cfg};
 
 
 
+our $micro = AI::MicroStructure->new($Structure);
+
+$absstructdir = $state->{path}->{"cwd/structures"};
+
 
 
 sub cleanArgs{
-    my ($key) = @_;
-    my @tmp=();
-    foreach(@ARGV){
-    push @tmp,$_ unless($_=~/$key/);}
-
-    @ARGV=@tmp;
+   my ($key) = @_;
+   my @tmp=();
+   foreach(@ARGV){
+   push @tmp,$_ unless($_=~/$key/);}
+   @ARGV=@tmp;
 }
-
-
 # private class method
 sub find_structures {
    my ( $class, @dirs ) = @_;
-
-
    $ALIEN{"base"} =  [map  @$_,
    map  { [ ( fileparse( $_, qr/\.pm$/ ) )[0] => $_ ] }
    map  { File::Glob::bsd_glob(
+   File::Spec->catfile( $_, ($structdir,"*") ) ) } @dirs];
 
+#  $ALIEN{"store"}=[split("\n",`cat @dirs/* | egrep -v "(our|my|use|sub|package)" | data-freq | egrep  -iv "^ [1]:`),
+ #                  split("\n",`cat @dirs/* | egrep -v "(our|my|use|sub|package)" | data-freq | egrep -i "^ [1]:`)];
 
-   File::Spec->catfile( $_, "*.pm" ) ) } @dirs];
-
-   $ALIEN{"store"}=[];
-
-
+##p %ALIEN;
 
    return @{$ALIEN{"base"}};
 }
@@ -103,85 +108,106 @@ sub find_modules {
 }
 
 
-our $micro = AI::MicroStructure->new($Structure);
-$absstructdir = $micro->{state}->{path}->{"cwd/structures"};
-
-
-push @CWD,$absstructdir;
-#push @CWD,$_ for @INC;
-
-
 
 $MICRO{$_} = 0 for keys %{{__PACKAGE__->find_structures(@CWD)} };
 $MODS{$_} = $_ for keys %{{__PACKAGE__->find_modules(@INC)} };
 $search = join("|",keys %MICRO);
 
+#p @{[__PACKAGE__->getComponents]};
+#die;
 #if( grep{/$search/} @ARGV ){ $Structure = $ARGV[0] unless(!$ARGV[0]); }
 
 # fetch the list of standard structures
 
 #print Dumper keys %MICRO;
-sub getComponents(){
+sub getComponents{
 
-  my $x= sprintf("%s",Dumper keys %MICRO);
 
-  return $x;
+  my $x= {};
+
+
+        $x->{"all_structures"} = [keys %MICRO];
+        $x->{"count_struct"} = sprintf(keys %MICRO);
+        $x->{"structures"} = {};
+        $x->{"structures"}->{"json"} = sprintf(`ls  /home/santex/repos/KnowledgeInterDisciplinary/data/json | egrep -i "($structure)";`);
+
+
+           foreach my $con (@{$x->{"all_structures"}}){
+            next unless($con!~/any/);
+            my @in = split("\n",eval{`cat $state->{path}->{"cwd/structures"}/$con.pm`;});
+
+#            my $conc=join("|",@{$x->{"nsubcon"}->{$state->{path}->{"cwd/structures"}}->{$con}->{all}});
+
+$x->{"structures"}->{$state->{path}->{"cwd/structures"}}->{$con}->{name} = [grep{$_}grep {!/(our|my|use|sub|use|package|#|__|1)/}split("\n",`cat $state->{path}->{"cwd/structures"}/$con.pm`)];#,
+#split("\n",grep{$con}@{$x->{"structures"}->{"json"}})];
+$x->{"structures"}->{$state->{path}->{"cwd/structures"}}->{$con}->{files}  =  [split("\n",`ls -R  /home/santex/repos/KnowledgeInterDisciplinary/data/json | egrep -i "($con)";`)];
+          }
+
+#$x->{"nsubcon"}->{$state->{path}->{"cwd/structures"}}->{$con}->{n} = grep{$_}grep {!/(our|my|use|sub|use|package|#|__|1)/}split("\n",`cat $state->{path}->{"cwd/structures"}/$con.pm`) ;
+
+#
+        $x->{"structures"}->{"json"} = [];
+#p @{[$x]};
+
+# $x->{"structures"}->{json}=[];
+        #my @got = [values  %{$x->{"structures"}}];
+
+         # p @got;
+  #      foreach(@got){
+ #         if(!$#_ && 0){
+#$x->{"structures"}->{$_} = [grep{$_}ssplit("^*\n",`cat '$state->{path}->{"cwd/structures"}/$_.pm'`)];
+#die();
+  #        }
+  #}
+
+ #       if(!@{$x->{"structures"}->{$_}}){
+
+#    $x->{"structures"}->{$_} =   [split("^*\n",`cat $state->{path}->{"cwd/structures"}/$_.pm |  | egrep -i "($_)\$"`)] for( @{$x->{"all structures"}});
+
+#          "glue"=>split("\n",`cat  $CWD[0]/* | egrep -v "(our|my|use|sub|package)"  | egrep -i "($structure)$"  | data-freq | egrep  -v "^ [1]:"`)};
+#
+ return $x;
 }
 
 
-# the functions actually hide an instance
-# END OF INITIALISATION
 
-# support for use AI::MicroStructure 'stars'
-# that automatically loads the required classes
+
 sub import {
-   my $class = shift;
-   # 'stars' is still first
-   my @structures = ( grep { $_ eq ':all' } @_ )
-   ? ( 'stars', grep { !/^(?:stars|:all)$/ } keys %MICRO )
-   : @_;
+    my $class = shift;
 
-   $Structure = $structures[0] if @structures;
-   my $micro = AI::MicroStructure->new( $Structure );
+    my @structures = ( grep { $_ eq ':all' } @_ )
+      ? ( 'foo', grep { !/^(?:foo|:all)$/ } keys %MICRO  ) # 'foo' is still first
+      : @_;
 
-   $absstructdir = $micro->{state}->{path}->{"cwd/structures"};
+    $Structure = $structures[0] if @structures;
+    $micro = AI::MicroStructure->new( $Structure );
 
-   # export the microname() function
-   no strict 'refs';
-   my $callpkg = caller;
-   *{"$callpkg\::microname"} = \&microname;   # standard structure
+    # export the microname() function
+    no strict 'refs';
+    my $callpkg = caller;
+    *{"$callpkg\::microname"} = \&microname;    # standard theme
 
-   # load the classes in @structures
-   for my $structure( @structures ) {
-   eval "require '$absstructdir/$structure.pm';".
-        "import  '$absstructdir/$structure.pm';";
-   croak $@ if $@;
-   *{"$callpkg\::micro$structure"} = sub { $micro->name( $structure, @_ ) };
-   }
+    # load the classes in @structures
+    for my $structure( @structures ) {
+        eval "require AI::MicroStructure::$structure; import AI::MicroStructure::$structure;";
+        croak $@ if $@;
+        *{"$callpkg\::micro$structure"} = sub { $micro->name( $structure, @_ ) };
+    }
 }
 
 sub new {
-   my ( $class, @tools ) = ( @_ );
-   my $structure;
-   $structure = shift @tools if @tools % 2;
-   $structure = $Structure unless $structure; # same default everywhere
-  #  my $driver = {};
-   #   $driver = AI::MicroStructure::Driver->new;
-
-   # defer croaking until name() is actually called
-   my $self = bless { structure => $structure,
-                     tools => { @tools }, micro => {}}, $class;
-
-
-    $self->{state}  =   AI::MicroStructure::Util::load_config();
-    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
-
-#    print Dumper $self;
-
-    return $self;
+    my ( $class, @args ) = ( @_ );
+    my $structure;
+    $structure = shift @args if @args % 2;
+    $structure = $Structure unless $structure; # same default everywhere
 
+    # defer croaking until name() is actually called
+    bless { structure => $structure, args => { @args }, micro => {} ,state=>$state}, $class;
 }
 
+
+
+
 sub _rearrange{
    my $self = shift;
    $self->{'payload'} = shift if @_;
@@ -277,6 +303,44 @@ sub fitnes {
 # main function
 sub microname { $micro->name( @_ ) };
 
+
+
+sub shitname {
+    my $self = shift;
+    my ( $structure, $count ) = ("any",1);
+
+    if (@_) {
+        ( $structure, $count ) = @_;
+        ( $structure, $count ) = ( $self->{structure}, $structure )
+          if $structure =~ /^(?:0|[1-9]\d*)$/;
+    }
+    else {
+        ( $structure, $count ) = ( $self->{structure}, 1 );
+    }
+
+    if( ! exists $self->{micro}{$structure} ) {
+        my ( $structure, $category ) = split /\//, $structure, 2;
+        if( ! $MICRO{$structure}  ) {
+            try{
+
+#            `micro new $structure`;
+
+            eval "require '$absstructdir/$structure.pm';";
+            $MICRO{$structure} = 1; # loaded
+            $self->{micro}{$structure}  = AI::MicroStructure->new($structure,category => $category);
+            print $self->{micro}{$structure}->name( $count );
+            return;
+            }  catch{
+
+            }
+        }
+
+    }
+
+
+
+}
+
 # corresponding method
 sub name {
    my $self = shift;
@@ -294,18 +358,58 @@ sub name {
    if( ! exists $self->{micro}{$structure} ) {
    if( ! $MICRO{$structure} ) {
    eval "require '$absstructdir/$structure.pm';";
-   #croak "MicroStructure list $structure does not exist!" if $@;
-
-   use AI::MicroStructure::any;
+   croak "MicroStructure list $structure does not exist!" if $@;
    $MICRO{$structure} = 1; # loaded
    }
    $self->{micro}{$structure} =
-   "AI::MicroStructure::$structure"->new( %{ $self->{tools} } );
+   "AI::MicroStructure::$structure"->new( %{ $self->{args} } );
    }
 
    $self->{micro}{$structure}->name( $count );
 }
 
+# corresponding method
+sub namex {
+   my $self = shift;
+   my ( $structure, $count ) = ("any",1);
+
+   if (@_) {
+   ( $structure, $count ) = @_;
+   ( $structure, $count ) = ( $self->{structure}, $structure )
+   if defined($structure) && $structure =~ /^(?:0|[1-9]\d*)$/;
+   }
+   else {
+   ( $structure, $count ) = ( $self->{structure}, 1 );
+   }
+
+   if( ! exists $self->{micro}{$structure} ) {
+   if( ! $MICRO{$structure} ) {
+    try {
+   eval "require '$absstructdir/$structure.pm';";
+   $MICRO{$structure} = 1; # loaded
+   croak "MicroStructure list $structure does not exist!" if $@;
+
+    }catch{
+
+      }
+   }
+   $self->{micro}{$structure} =
+   "AI::MicroStructure::$structure"->new( %{ $self->{args} } );
+
+
+
+
+
+
+
+   }
+
+   $self->{micro}{$structure}->name( $count );
+}
+
+
+
+
 
 
 # other methods
@@ -348,17 +452,11 @@ sub getBundle {
 
    my $self = shift;
 
-    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
 
 
 my @structures = grep { !/^(?:any)/ } AI::MicroStructure->structures;
 my @micros;
 my @search=[];
-
-
-
-
-
 for my $structure (@structures) {
    no strict 'refs';
    eval "require '$absstructdir/$structure.pm';";
@@ -599,13 +697,14 @@ my $self = shift;
 my $StructureName = shift;
 my $data = shift;
 
-    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
-    $StructureName = lc $self->trim(`micro`) unless($StructureName);
+    if($StructureName){
+    #$StructureName = lc $self->trim(`micro`) unless($StructureName);
     my $file = "$absstructdir/$StructureName.pm";
-    print `mkdir $absstructdir` unless(-d $absstructdir);
+
+    print `mkdir -p $absstructdir` unless(-d $absstructdir);
     my $fh;
 
-    open($fh,">$file") || die $!;
+    open($fh,">$file") || warn @{[$file,$!]};
 
     print $fh $self->getBlank($StructureName,$data);
 
@@ -613,6 +712,7 @@ my $data = shift;
     $Structure = $StructureName;
     push @CWD,$file;
     return 1;
+  }
 }
 
 
@@ -622,120 +722,35 @@ sub drop {
 my $self = shift;
 my $StructureName = shift;
 
-my @fh = grep{/$StructureName.pm/}__PACKAGE__->find_structures(@CWD);
-
-
-  if(defined($fh[0]) &&  `ls $fh[0]`)
-  {
-    print  `rm $fh[0]`;
-
-  }else{
-
-   croak "The structure $StructureName does not exist!";
-
-  }
+my @file = grep{/$StructureName.pm/}map{File::Glob::bsd_glob(
+File::Spec->catfile( $_, ($structdir,"*.pm") ) )}@CWD;
+my $fh = shift @file;
+if(`ls $fh`)
+{
 
+print  `rm $fh`;
+}
+  #push @CWD,$file[1];
 
   return 1;
 }
 
-sub help {
 
-my $self = shift;
-my $usage = << 'EOT';
-
-  #current status
-  #did you create a micro structure yet ?
-  #try something like this
-
-  $ micro new ufo;      # creates a structure called ufo
-
-  $ micro drop ufo;     # deletes the structure called ufo
-
-  $ micro structures;   # shows all structure's you currently have
-
-  #after creation of a structure you can access it in lots of ways
-
-
-
-  $ micro;             # one word of a random structure
-
-  $ micro ufo;         # one word of the ufo structure
-
-  $ micro ufo all;     # all words of the ufo structure
-
-  $ micro ufo 5;       # 5 random words of the ufo structure
-
-  $ micro any 10;      # 10 random words of any structure you have created
-
-
-  $ micro --init        # initializes active memory
-
-  $ micro --export      # export relations from couchdb into git repo and tag data
-
-
-  # oneliners i like to use
-
-  $  for i in `micro structures`; do echo $i; done;       # echos all the structures
-
-  $  for i in `micro ufo all`;   do echo $i; done;       # echos all words in ufo
-
-  $  for i in `micro structures`; do micro all $i; done;  # echos all stuctures all words
-
-  $  for i in `micro ufo all`;   do micro new $i; done;  # new structure for all words in ufo
-
-  $  for i in `micro ufo all`;   do micro-wiki $i; done; # push all words against the wiki plugin dont forget setting user & password in /usr/local/bin/micro-wiki
-
-  ###################################################################################
-  # try to follow the logic combine
-  # your-word=micro new ? ->concept->concepts->relations->node
-
-
-  $ micro new biology
-  $ micro new biological_process
-
-  $ for i in `micro structures`; do
-  $ for y in `micro all $i `; do
-  $ echo "$i=$y";
-  $ micro new $y;
-  $ done
-  $ done
-
-  #!!!!!###Hard cpu to expect ### make sure couch is on   ######  or disable the store methode in micro-wiki and print $doc or consume otherweise
-  # test as single before you loope
-
-  $ micro-wiki ufo
-
-  # proceed
-
-  $ for i in `micro structures`; do
-  $ for y in `micro all $i `; do
-  $ echo "$i=$y";
-  $ micro-wiki $y;
-  $ done
-  $ done
-
-
-EOT
-
-
-
-return $usage;
+sub help{
 
 }
 
 
-BEGIN {
-
-
-}
 
 END{
 
 if($init){}
 if($available){}
 if($lib){}
-if($list){}
+if($list){
+p @{[__PACKAGE__->getComponents]};
+
+  }
 if($use){}
 if($off){}
 if($switch){}
@@ -748,7 +763,7 @@ if($version){
 
 
 if($help) {
-    printf($micro->help());
+    printf(__PACKAGE__->help());
     exit(0);
 
 }
@@ -758,7 +773,7 @@ if($help) {
 
 
 if($drop == 1) {
-   $micro->drop($StructureName);
+   __PACKAGE__->drop($StructureName);
    exit 0;
 }
 
@@ -770,18 +785,23 @@ if($new==1){
   my $data = decode_json(lc`micro-sense $StructureName words`);
 
 
+
   my $char;
   my $line;
   my $senses=@{$data->{"senses"}};
    $senses= 0 unless($senses);
+ if(!$verbose){
 
   printf("\n
   \033[0;34m
   %s
   Type: the number you choose 1..$senses
-  \033[0m",$micro->usage($StructureName,$senses,$data));
-
+  \033[0m",__PACKAGE__->usage($StructureName,$senses,$data));
+ }
   $line = 1 unless($senses != 1);
+  if($verbose){
+    $line=1;
+  }
   chomp($line = <STDIN>) unless($line);
 
   my $d = join("#",@{$data->{rows}->{search}});
@@ -790,7 +810,7 @@ if($new==1){
   @{$data->{rows}->{"search"}}=split("#",join("",@d));
 
   if($line>0){
-   $micro->save_new($StructureName,$data,$line);
+   __PACKAGE__->save_new($StructureName,$data,$line);
    exit 0;
   }else{
 
@@ -804,7 +824,7 @@ if($new==1){
   }
 
   if($write == 1) {
-   $micro->save_default();
+   __PACKAGE__->save_default();
   }
 }
 
@@ -905,6 +925,9 @@ foreach my $sensnrx (sort keys %{$data->{"rows"}->{"senses"}})
 return $usage;
 }
 
+1;
+
+__END__
 
 1;
 
@@ -953,4 +976,87 @@ __END__
 =head1 SEE ALSO
 
   AI-MicroStructure
-=cut
+  AI-MicroStructure-Cache
+  AI-MicroStructure-Deamon
+  AI-MicroStructure-Relations
+  AI-MicroStructure-Concept
+  AI-MicroStructure-Data
+  AI-MicroStructure-Driver
+  AI-MicroStructure-Plugin-Pdf
+  AI-MicroStructure-Plugin-Twitter
+  AI-MicroStructure-Plugin-Wiki
+
+
+
+__DATA__
+
+
+
+our $VERSION = '0.014';
+our $Structure = 'any'; # default structure
+our $CODESET = 'utf8';
+our $LANG = '';
+our %MICRO;
+our %MODS;
+our %ALIEN;
+our $str = "[A-Z]";
+our $special = "any";
+our $search;
+our $data={};
+our $item="";
+our @items;
+our @a=();
+
+
+
+
+
+our ($new, $write,$drop) =(0,0,0);
+
+my $state = AI::MicroStructure::util::load_config(); my @CWD=$state->{cwd}; my $config=$state->{cfg};
+our $structdir = "structures";
+our $absstructdir = "$CWD[0]/$structdir";
+
+if( grep{/\bnew\b/} @ARGV ){ $new = 1; cleanArgs("new"); }
+if( grep{/\bwrite\b/} @ARGV ){ $write = 1; cleanArgs("write");  };
+if( grep{/\bdrop\b/} @ARGV ){ $drop = 1; cleanArgs("drop");  };
+
+our $StructureName = $ARGV[0]; # default structure
+our $structure = $ARGV[0]; # default structure
+
+##########################################################################
+cat  $dir/* | egrep -v "(our|my|use|sub|package)"  | egrep -i "(instance|animal|whale|mammal|sea)$" | egrep  "^ [1]:"
+ 1: andaman_sea
+ 1: swansea
+ 1: domesticanimal
+ 1: fictionalanimal
+ 1: marineanimal
+
+
+
+cat  $dir/* | egrep -v "(our|my|use|sub|package)"  | egrep -i "(instance|animal|whale|mammal|sea)$"  | data-freq | egrep  -v "^ [1]:"
+84: animal
+26: mammal
+25: eutherian_mammal
+25: placental_mammal
+12: domesticated_animal
+11: domestic_animal
+ 6: predatory_animal
+ 6: sea_animal
+ 5: fictional_animal
+ 5: marine_animal
+ 5: range_animal
+ 5: work_animal
+ 5: hoofed_mammal
+ 3: artiodactyl_mammal
+ 2: perissodactyl_mammal
+ 2: instance
+ 2: moss_animal
+ 2: anglesea
+ 2: female_mammal
+ 2: fossorial_mammal
+ 2: mediterranean_sea
+ 2: aquatic_mammal
+ 2: cetacean_mammal
+ 2: toothed_whale
+ 2: whale
